@@ -43,7 +43,7 @@ class R3sponse(object):
 		for key, value in variables.items():
 			response[key] = value
 		r3sponse.log(message=response["message"], log_level=log_level, save=save)
-		if django: response = JsonResponse(response)
+		if django: response = JsonResponse(response.dict(), safe=False)
 		return response
 	def error_response(self,
 		# the error message.
@@ -60,7 +60,7 @@ class R3sponse(object):
 		response["message"] = None
 		response["error"] = error
 		r3sponse.log(error=response["error"], log_level=log_level, save=save)
-		if django: response = JsonResponse(response)
+		if django: response = JsonResponse(response.dict(), safe=False)
 		return response
 		#
 	def success(self, response):
@@ -225,14 +225,26 @@ class ResponseObject(object):
 			raise TypeError("You can only self assign with a dictionary as parameter.")
 		for key,value in dictionary.items():
 			self[key] = value
+	# clean default values.
+	def clean(self):
+		for i in ["error", "message", "success"]:
+			del self[i]
+			#except: a=1
+		return self
 	# support item assignment.
 	def __setitem__(self, key, value):
 		setattr(self, key, value)
 	def __getitem__(self, key):
 		return getattr(self, key)
+	def __delitem__(self, key):
+		delattr(self, key)
 	# string format.
 	def __str__(self):
 		return json.dumps(self.dict(), indent=4)
+	def json(self,):
+		return json.dumps(self, default=lambda o: o.__dict__)
+	#def __dict__(self):
+	#	return json.dumps(self.dict(), indent=4)
 
 # initialized objects.
 r3sponse = R3sponse()
